"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const AsyncFilterIterator_1 = require("../lib/AsyncFilterIterator");
const asynciterator_1 = require("asynciterator");
describe('AsyncFilterIterator', () => {
    describe('The AsyncFilterIterator module', () => {
        it('should be a function', () => {
            expect(AsyncFilterIterator_1.AsyncFilterIterator).toBeInstanceOf(Function);
        });
        it('should be an AsyncFilterIterator constructor', () => {
            expect(new AsyncFilterIterator_1.AsyncFilterIterator())
                .toBeInstanceOf(AsyncFilterIterator_1.AsyncFilterIterator);
            expect(new AsyncFilterIterator_1.AsyncFilterIterator())
                .toBeInstanceOf(asynciterator_1.TransformIterator);
        });
        it('should not be able to create new ActorQueryOperationFilterDirect objects without \'new\'', () => {
            expect(() => { AsyncFilterIterator_1.AsyncFilterIterator(); }).toThrow();
        });
    });
    describe('An AsyncFilterIterator instance', () => {
        let source;
        let input;
        const regFilter = (item) => Promise.resolve((item === 'keepMeIn'));
        beforeEach(() => {
            input = ['filterMeOut', 'filterMeOut', 'keepMeIn', 'filterMeOut', 'keepMeIn'];
            source = new asynciterator_1.ArrayIterator(input);
        });
        it('ends when the stream ends', (done) => {
            const eStream = new AsyncFilterIterator_1.AsyncFilterIterator(regFilter, source);
            eStream.on('error', (err) => fail(err));
            eStream.on('end', (data) => done());
            eStream.each(() => { return; });
        });
        it('emits the correct amount of items', (done) => {
            const eStream = new AsyncFilterIterator_1.AsyncFilterIterator(regFilter, source);
            let counter = 0;
            eStream.on('error', (err) => fail(err));
            eStream.on('end', (data) => {
                expect(counter).toBe(2);
                done();
            });
            eStream.on('data', (data) => counter++);
        });
        it('should filter correctly', (done) => {
            const eStream = new AsyncFilterIterator_1.AsyncFilterIterator(regFilter, source);
            eStream.on('error', (err) => fail(err));
            eStream.on('end', (data) => done());
            eStream.on('data', (data) => {
                expect(data).toBe('keepMeIn');
            });
        });
        it('should return the full stream for a truthy filter', (done) => {
            const filter = (item) => Promise.resolve(true);
            const eStream = new AsyncFilterIterator_1.AsyncFilterIterator(filter, source);
            let counter = 0;
            eStream.on('error', (err) => fail(err));
            eStream.on('end', (data) => {
                expect(counter).toBe(input.length);
                done();
            });
            eStream.on('data', (data) => counter++);
        });
        it('should return an empty stream for a falsy filter', (done) => {
            const filter = (item) => Promise.resolve(false);
            const eStream = new AsyncFilterIterator_1.AsyncFilterIterator(filter, source);
            let counter = 0;
            eStream.on('error', (err) => fail(err));
            eStream.on('end', (data) => {
                expect(counter).toBe(0);
                done();
            });
            eStream.on('data', (data) => counter++);
        });
        it('should emit an error for an erroring filter', (done) => {
            const filter = (item) => Promise.reject('errors yo');
            const eStream = new AsyncFilterIterator_1.AsyncFilterIterator(filter, source);
            eStream.on('error', (err) => done());
            eStream.on('end', (data) => done());
            eStream.on('data', (data) => fail());
        });
    });
});
//# sourceMappingURL=AsyncFilterIterator.test.js.map